==> freecad_0.16.6712%2Bdfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Glavne postavke</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Generalne OpenSCAD opcije</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>OpenSCAD izvršna datoteka</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executeable</source>
      <translation>Putanja do OpenSCAD izvršne datoteke</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>OpenSCAD uvoz</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>koristi view provider u prikazu stabla</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Ako je označeno, Multimatrix objekt će biti parametarski</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Koristi Multimatrix opcije</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>Maksimalni broj ploha na poligonu, prizmi i slično. Ako je fn veći od ove vrijednosti, smatra se da je objekt obli. O označava da nema limita</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Maksimalni broj ploha za poligone (fn)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>OpenSCAD izvoz</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>Maksimalna veličina fragmenta</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="215"/>
      <source>minimum angle for a fragment</source>
      <translation>Minimalni kut fragmenta</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>kutni (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="272"/>
      <source>minimum size of a fragment</source>
      <translation>minimalna veličina fragmenta</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>veličina (fn)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>konveksnost</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Mesh rezervni plan</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Defleksija</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>defleksija</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Opcije stvaranja Mesh-a</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation type="unfinished">If this is checked, Features will claim their children in the tree view</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation type="unfinished">Print debug information in the Console</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="OpenSCADCommands.py" line="141"/>
      <source>Convert Edges to Faces</source>
      <translation>Pretvori rubove u površine</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="220"/>
      <source>Please select 3 objects first</source>
      <translation>Molim odaberite tri oblika</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1118"/>
      <source>Unsupported Function</source>
      <translation>Nepodržana funkcija</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1118"/>
      <source>Press OK</source>
      <translation>Pritisnite OK</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="264"/>
      <source>Add</source>
      <translation>Dodaj</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="265"/>
      <source>Clear</source>
      <translation>Brisanje</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="266"/>
      <source>as Mesh</source>
      <translation>kao Mesh</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="267"/>
      <source>Add OpenSCAD Element</source>
      <translation>Dodaj OpenSCAD Element</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="340"/>
      <source>Perform</source>
      <translation type="unfinished">Perform</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="341"/>
      <source>Mesh Boolean</source>
      <translation type="unfinished">Mesh Boolean</translation>
    </message>
    <message>
      <location filename="OpenSCADUtils.py" line="560"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation type="unfinished">Error all shapes must be either 2D or both must be 3D</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="91"/>
      <source>Unable to explode %s</source>
      <translation type="unfinished">Unable to explode %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="OpenSCADCommands.py" line="382"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Dodaj OpenSCAD Element...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="384"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Dodaj OpenSCAD element unošenjem OpenSCAD koda i pokretanjem OpenSCAD binarne datoteke</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="OpenSCADCommands.py" line="118"/>
      <source>Color Shapes</source>
      <translation>Oboji oblike</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="120"/>
      <source>Color Shapes by validity and type</source>
      <translation>Oboji oblike po tipu i valjanosti</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="OpenSCADCommands.py" line="139"/>
      <source>Convert Edges To Faces</source>
      <translation>Pretvori rubove u površine</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="OpenSCADCommands.py" line="200"/>
      <source>Expand Placements</source>
      <translation>Proširi postavljanja</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="202"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Proširi sva postavljanja niže u stablu svojstava</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="OpenSCADCommands.py" line="100"/>
      <source>Explode Group</source>
      <translation type="unfinished">Explode Group</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="102"/>
      <source>remove fusion, apply placement to children and color randomly</source>
      <translation type="unfinished">remove fusion, apply placement to children and color randomly</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="OpenSCADCommands.py" line="417"/>
      <source>Hull</source>
      <translation type="unfinished">Hull</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="419"/>
      <source>Perform Hull</source>
      <translation type="unfinished">Perform Hull</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="181"/>
      <source>Increase Tolerance Feature</source>
      <translation type="unfinished">Increase Tolerance Feature</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="183"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation type="unfinished">Create Feature that allows to increase the tolerance</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="OpenSCADCommands.py" line="396"/>
      <source>Mesh Boolean...</source>
      <translation type="unfinished">Mesh Boolean...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="398"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation.</source>
      <translation type="unfinished">Export objects as meshes and use OpenSCAD to perform a boolean operation.</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="OpenSCADCommands.py" line="438"/>
      <source>Minkowski</source>
      <translation type="unfinished">Minkowski</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="440"/>
      <source>Perform Minkowski</source>
      <translation type="unfinished">Perform Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="160"/>
      <source>Refine Shape Feature</source>
      <translation>Izgladi oblik svojstvo</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="162"/>
      <source>Create Refine Shape Feature</source>
      <translation>Kreiraj "Izgladi Oblik" svojstvo</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="OpenSCADCommands.py" line="239"/>
      <source>Remove Objects and their Children</source>
      <translation>Izbriši objekte i njihove potomke</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="241"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Briše odabrani objekt i svu djecu koja nisu referencirana od ostalih objekata</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="OpenSCADCommands.py" line="224"/>
      <source>Replace Object</source>
      <translation>Zamjeni objekt</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="226"/>
      <source>Replace an object in the Feature Tree. Please select old, new and parent object</source>
      <translation>Zamjeni objekt u stablu. Odaberite stari objekt, novi i roditelja</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="InitGui.py" line="80"/>
      <source>OpenSCAD Part tools</source>
      <translation type="unfinished">OpenSCAD Part tools</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="InitGui.py" line="78"/>
      <source>OpenSCADTools</source>
      <translation type="unfinished">OpenSCADTools</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1%2Bdfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="hr" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Glavne postavke</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Generalne OpenSCAD Opcije</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>OpenSCAD izvršna datoteka</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>OpenSCAD uvoz</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>koristi view provider u prikazu stabla</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Ako je označeno, Multimatrix objekt će biti parametarski</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Koristi Multimatrix opcije</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>Maksimalni broj ploha na poligonu, prizmi i slično. Ako je fn veći od ove vrijednosti, smatra se da je objekt obli. O označava da nema limita</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Maksimalni broj ploha za poligone (fn)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>OpenSCAD izvoz</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>Maksimalna veličina fragmenta</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>kutni (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>veličina (fn)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>konveksnost</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Mesh rezervni plan</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Defleksija</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>defleksija</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Opcije stvaranja Mesh-a</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Ako je označeno, svojstva će sadržavati njihove potomke u prikazu stabla</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>Prikaži debug informacije u konzoli</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executable</source>
      <translation>Putanja do OpenSCAD izvršne datoteke</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="215"/>
      <source>Minimum angle for a fragment</source>
      <translation>Minimalni kut fragmenta</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="272"/>
      <source>Minimum size of a fragment</source>
      <translation>Minimalna veličina fragmenta</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="OpenSCADCommands.py" line="149"/>
      <source>Convert Edges to Faces</source>
      <translation>Pretvori rubove u površine</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="309"/>
      <source>Please select 3 objects first</source>
      <translation>Molim odaberite tri oblika</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Unsupported Function</source>
      <translation>Nepodržana funkcija</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Press OK</source>
      <translation>Pritisnite OK</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="347"/>
      <source>Add</source>
      <translation>Dodaj</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="348"/>
      <source>Clear</source>
      <translation>Brisanje</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="349"/>
      <source>as Mesh</source>
      <translation>kao Mesh</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="350"/>
      <source>Add OpenSCAD Element</source>
      <translation>Dodaj OpenSCAD Element</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="423"/>
      <source>Perform</source>
      <translation>Izvedi</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="424"/>
      <source>Mesh Boolean</source>
      <translation>Booleova mreža</translation>
    </message>
    <message>
      <location filename="OpenSCADUtils.py" line="623"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Greška, svi oblici moraju biti 2D ili oba moraju biti 3D</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="102"/>
      <source>Unable to explode %s</source>
      <translation>Nije moguće razdijeliti %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="OpenSCADCommands.py" line="464"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Dodaj OpenSCAD Element...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="468"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Dodaj OpenSCAD element unošenjem OpenSCAD koda i pokretanjem OpenSCAD binarne datoteke</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="OpenSCADCommands.py" line="126"/>
      <source>Color Shapes</source>
      <translation>Oboji oblike</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="129"/>
      <source>Color Shapes by validity and type</source>
      <translation>Oboji oblike po tipu i valjanosti</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="OpenSCADCommands.py" line="146"/>
      <source>Convert Edges To Faces</source>
      <translation>Pretvori rubove u površine</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="OpenSCADCommands.py" line="291"/>
      <source>Expand Placements</source>
      <translation>Proširi postavljanja</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="294"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Proširi sva postavljanja niže u stablu svojstava</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="OpenSCADCommands.py" line="110"/>
      <source>Explode Group</source>
      <translation>Razdijeli grupu</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="113"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation>Ukloni fuziju, dodaj položaj na potomke i obojaj ih slučajno</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="OpenSCADCommands.py" line="497"/>
      <source>Hull</source>
      <translation>Trup</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="500"/>
      <source>Perform Hull</source>
      <translation>Izvođenje trupa</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="274"/>
      <source>Increase Tolerance Feature</source>
      <translation>Povećaj toleranciju</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="277"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Stvaranja svojstva koje omogućuje da se poveća tolerancija</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="OpenSCADCommands.py" line="477"/>
      <source>Mesh Boolean...</source>
      <translation>Booleova mreža...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="481"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation>Izvoz objekata kao mreže i koristi OpenSCAD za izvođenje logičkih ( boolean) operacija</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="OpenSCADCommands.py" line="516"/>
      <source>Minkowski</source>
      <translation>Minkowski</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="519"/>
      <source>Perform Minkowski</source>
      <translation>Izvođenje Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MirrorMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="195"/>
      <source>Mirror Mesh Feature...</source>
      <translation>Svojstva zrcaljenja mreža...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="198"/>
      <source>Create Mirror Mesh Feature</source>
      <translation>Stvori svojstvo zrcaljenja mreža</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="165"/>
      <source>Refine Shape Feature</source>
      <translation>Izgladi oblik svojstvo</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="168"/>
      <source>Create Refine Shape Feature</source>
      <translation>Kreiraj "Izgladi Oblik" svojstvo</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="OpenSCADCommands.py" line="324"/>
      <source>Remove Objects and their Children</source>
      <translation>Izbriši objekte i njihove potomke</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="327"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Briše odabrani objekt i sve potomke koji nisu referencirani od ostalih objekata</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="OpenSCADCommands.py" line="312"/>
      <source>Replace Object</source>
      <translation>Zamjeni objekt</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="315"/>
      <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
      <translation>Zamijeni objekt u stablu svojstava. Odaberite stari, novi, i roditeljski objekt</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ResizeMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="254"/>
      <source>Resize Mesh Feature...</source>
      <translation>Skaliranje svojstava mreže ...

</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="258"/>
      <source>Create Resize Mesh Feature</source>
      <translation>Stvori Svojstvo Skaliranje Mreža</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ScaleMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="224"/>
      <source>Scale Mesh Feature...</source>
      <translation>Skaliranje Svojstava  Mreže...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="228"/>
      <source>Create Scale Mesh Feature</source>
      <translation>Stvori Svojstvo Skaliranje Mreža</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="InitGui.py" line="83"/>
      <source>OpenSCAD Part tools</source>
      <translation>OpenSCAD alati za Dio</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="InitGui.py" line="81"/>
      <source>OpenSCADTools</source>
      <translation>OpenSCAD Alati</translation>
    </message>
  </context>
</TS>
